Current Network Status

Current Network Status Last Updated: Wed Feb 17 15:22:05 IST 2016 Updated every 90 seconds Nagios® Core™ 3.5.0 - www.nagios.org Logged in as nagiosadmin
View History For all hosts View Notifications For All Hosts View Host Status Detail For All Hosts
| Host Status Totals
Up | Down | Unreachable | Pending
--- | --- | --- | ---
24 | 2 | 0 | 0
All Problems | All Types
--- | ---
2 | 26
| Service Status Totals
Ok | Warning | Unknown | Critical | Pending
--- | --- | --- | --- | ---
742 | 7 | 1 | 7 | 0
All Problems | All Types
--- | ---
15 | 757

| Service Status Details For All Hosts |

Limit Results:

Host | Service | Status | Last Check | Duration | Attempt | Status Information
--- | --- | --- | --- | --- | --- | ---
compute-0-0.local
CPU load
| WARNING | 2016-02-09 13:05:32 | 8d 2h 16m 33s | 1/1 | high CPU load
CPU utilization
| OK | 2016-02-17 15:21:22 | 14d 1h 29m 34s | 1/1 | OK - user: 0.5%, system: 0.4%, wait: 2.4%, total: 3.3%
Disk IO SUMMARY
| OK | 2016-02-17 15:21:22 | 14d 1h 28m 34s | 1/1 | OK - 0.00 B/sec read, 1.84 MB/sec write, IOs: 89.00/sec
compute-0-1.local
CPU load
| OK | 2016-02-17 15:21:22 | 0d 1h 48m 43s | 1/1 | OK - 15min load 1.27 at 24 CPUs
CPU utilization
| OK | 2016-02-17 15:21:22 | 14d 1h 29m 19s | 1/1 | OK - user: 0.5%, system: 0.4%, wait: 2.2%, total: 3.1%
check_load
| CRITICAL | 2016-02-16 14:27:06 | 1d 0h 54m 59s | 1/1 | Critical Error
os-ceilometer-00.local
CPU load
| OK | 2016-02-17 15:21:51 | 14d 0h 48m 4s | 1/1 | OK - 15min load 0.36 at 2 CPUs
CPU utilization
| OK | 2016-02-17 15:21:51 | 14d 0h 48m 4s | 1/1 | OK - user: 2.7%, system: 1.0%, wait: 0.1%, total: 3.8%
os-ceilometer-01.local
CPU load
| OK | 2016-02-17 15:21:51 | 14d 0h 48m 2s | 1/1 | OK - 15min load 0.44 at 2 CPUs
CPU utilization
| OK | 2016-02-17 15:21:51 | 14d 0h 48m 2s | 1/1 | OK - user: 2.7%, system: 1.1%, wait: 0.2%, total: 4.1%

Results 1 - 757 of 757 Matching Services